aboutsummaryrefslogtreecommitdiffstats
path: root/app/scripts/keyring-controller.js
diff options
context:
space:
mode:
authorDan Finlay <dan@danfinlay.com>2017-09-23 05:13:56 +0800
committerDan Finlay <dan@danfinlay.com>2017-09-23 05:13:56 +0800
commitf01b0a818ba67c2549f14382056534768a255e5b (patch)
tree4e9baaee28b9aefbf7f44c5229cfe5309e75e6f9 /app/scripts/keyring-controller.js
parentf9d2f523c628228a77c28e7d46d08151453a47bc (diff)
downloadtangerine-wallet-browser-f01b0a818ba67c2549f14382056534768a255e5b.tar.gz
tangerine-wallet-browser-f01b0a818ba67c2549f14382056534768a255e5b.tar.zst
tangerine-wallet-browser-f01b0a818ba67c2549f14382056534768a255e5b.zip
Fix account-tracker references
Diffstat (limited to 'app/scripts/keyring-controller.js')
-rw-r--r--app/scripts/keyring-controller.js10
1 files changed, 5 insertions, 5 deletions
diff --git a/app/scripts/keyring-controller.js b/app/scripts/keyring-controller.js
index fd57fac70..fa470dd89 100644
--- a/app/scripts/keyring-controller.js
+++ b/app/scripts/keyring-controller.js
@@ -35,7 +35,7 @@ class KeyringController extends EventEmitter {
keyrings: [],
identities: {},
})
- this.ethStore = opts.ethStore
+ this.accountTracker = opts.accountTracker
this.encryptor = encryptor
this.keyrings = []
this.getNetwork = opts.getNetwork
@@ -338,7 +338,7 @@ class KeyringController extends EventEmitter {
//
// Initializes the provided account array
// Gives them numerically incremented nicknames,
// and adds them to the ethStore for regular balance checking.
setupAccounts (accounts) {
return this.getAccounts()
.then((loadedAccounts) => {
@@ -361,7 +361,7 @@ class KeyringController extends EventEmitter {
throw new Error('Problem loading account.')
}
const address = normalizeAddress(account)
- this.ethStore.addAccount(address)
+ this.accountTracker.addAccount(address)
return this.createNickname(address)
}
@@ -567,12 +567,12 @@ class KeyringController extends EventEmitter {
clearKeyrings () {
let accounts
try {
- accounts = Object.keys(this.ethStore.getState())
+ accounts = Object.keys(this.accountTracker.getState())
} catch (e) {
accounts = []
}
accounts.forEach((address) => {
- this.ethStore.removeAccount(address)
+ this.accountTracker.removeAccount(address)
})
// clear keyrings from memory
@@ -338,7 +338,7 @@ class KeyringController extends EventEmitter {
// Initializes the provided account array
// Gives them numerically incremented nicknames,
- // and adds them to the ethStore for regular balance checking.
+ // and adds them to the accountTracker for regular balance checking.
setupAccounts (accounts) {
return this.getAccounts()